@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import enum
 import functools
@@ -69,6 +71,7 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
     def __init__(self, endpoint: EndpointType, is_server: bool = True):
         self._endpoint: EndpointType = endpoint
         self._attr_cache: Dict[int, Any] = {}
+        self.unsupported_attributes: set[int | str] = set()
         self._listeners = {}
         if is_server:
             self._type: ClusterType = ClusterType.Server
@@ -260,14 +263,14 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
 
     async def read_attributes(
         self,
-        attributes,
-        allow_cache=False,
-        only_cache=False,
-        manufacturer=None,
+        attributes: list[int | str],
+        allow_cache: bool = False,
+        only_cache: bool = False,
+        manufacturer: int | t.uint16_t | None = None,
     ):
         success, failure = {}, {}
-        attribute_ids = []
-        orig_attributes = {}
+        attribute_ids: list[int] = []
+        orig_attributes: dict[int, int | str] = {}
         for attribute in attributes:
             if isinstance(attribute, str):
                 attrid = self.attridx[attribute]
@@ -281,6 +284,8 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
             for idx, attribute in enumerate(attribute_ids):
                 if attribute in self._attr_cache:
                     success[attributes[idx]] = self._attr_cache[attribute]
+                elif attribute in self.unsupported_attributes:
+                    failure[attributes[idx]] = foundation.Status.UNSUPPORTED_ATTRIBUTE
                 else:
                     to_read.append(attribute)
         else:
@@ -313,6 +318,8 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
                     self._update_attribute(record.attrid, value)
                     success[orig_attribute] = value
                 else:
+                    if record.status == foundation.Status.UNSUPPORTED_ATTRIBUTE:
+                        self.add_unsupported_attribute(record.attrid)
                     failure[orig_attribute] = record.status
 
         return success, failure
@@ -425,22 +432,23 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
 
     def configure_reporting(
         self,
-        attribute: Union[int, str],
+        attribute: int | str,
         min_interval: int,
         max_interval: int,
         reportable_change: int,
-        manufacturer: Optional[int] = None,
+        manufacturer: int | None = None,
     ) -> Coroutine:
-        cfg = self._attr_reporting_rec(
-            attribute, min_interval, max_interval, reportable_change
+        """Configure attribute reporting for a single attribute."""
+        return self.configure_reporting_multiple(
+            {attribute: (min_interval, max_interval, reportable_change)},
+            manufacturer=manufacturer,
         )
-        return self._configure_reporting([cfg], manufacturer=manufacturer)
 
-    def configure_reporting_multiple(
+    async def configure_reporting_multiple(
         self,
-        attributes: Dict[Union[int, str], Tuple[int, int, int]],
-        manufacturer: Optional[int] = None,
-    ) -> Coroutine:
+        attributes: dict[int | str, tuple[int, int, int]],
+        manufacturer: int | None = None,
+    ) -> list[foundation.ConfigureReportingResponseRecord]:
         """Configure attribute reporting for multiple attributes in the same request.
 
         :param attributes: dict of attributes to configure attribute reporting.
@@ -456,7 +464,25 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
             self._attr_reporting_rec(attr, rep[0], rep[1], rep[2])
             for attr, rep in attributes.items()
         ]
-        return self._configure_reporting(cfg, manufacturer=manufacturer)
+        res = await self._configure_reporting(cfg, manufacturer=manufacturer)
+
+        # Parse configure reporting result for unsupported attributes
+        records = res[0]
+        if (
+            isinstance(records, list)
+            and not (
+                len(records) == 1 and records[0].status == foundation.Status.SUCCESS
+            )
+            and len(records) >= 0
+        ):
+            failed = [
+                r.attrid
+                for r in records
+                if r.status == foundation.Status.UNSUPPORTED_ATTRIBUTE
+            ]
+            for attr in failed:
+                self.add_unsupported_attribute(attr)
+        return res
 
     def command(
         self,
@@ -633,6 +659,24 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
             )
         )
 
+    def add_unsupported_attribute(
+        self, attr: int | str, inhibit_events: bool = False
+    ) -> None:
+        """Adds unsupported attribute."""
+
+        if attr in self.unsupported_attributes:
+            return
+
+        self.unsupported_attributes.add(attr)
+        if isinstance(attr, int):
+            if not inhibit_events:
+                self.listener_event("unsupported_attribute_added", attr)
+            reverse_attr = self.attributes.get(attr, (None,))[0]
+        else:
+            reverse_attr = self.attridx.get(attr)
+        if not (reverse_attr is None or reverse_attr in self.unsupported_attributes):
+            self.add_unsupported_attribute(reverse_attr, inhibit_events)
+
 
 class ClusterPersistingListener:
     def __init__(self, applistener, cluster):
@@ -648,6 +692,10 @@ class ClusterPersistingListener:
     def general_command(self, *args, **kwargs):
         pass
 
+    def unsupported_attribute_added(self, attrid: int) -> None:
+        """An unsupported attribute was added."""
+        self._applistener.unsupported_attribute_added(self._cluster, attrid)
+
 
 # Import to populate the registry
 from . import clusters  # noqa: F401, E402, isort:skip
