@@ -1,24 +1,47 @@
+from __future__ import annotations
+
 import typing
 
 import zigpy.types as t
 
 
+class _PowerDescriptorEnums:
+    class CurrentPowerMode(t.enum4):
+        RxOnSyncedWithNodeDesc = 0b0000
+        RxOnPeriodically = 0b0001
+        RxOnWhenStimulated = 0b0010
+
+    class PowerSources(t.bitmap4):
+        MainsPower = 0b0001
+        RechargeableBattery = 0b0010
+        DisposableBattery = 0b0100
+        Reserved = 0b1000
+
+    class PowerSourceLevel(t.enum4):
+        Critical = 0b0000
+        Percent33 = 0b0100
+        Percent66 = 0b1000
+        Percent100 = 0b1100
+
+
 class PowerDescriptor(t.Struct):
-    _fields = [
-        ("byte_1", 1),  # Current power mode 4, Available power sources 4
-        ("byte_2", 1),  # Current power source 4, Current power source level 4
-    ]
+    CurrentPowerMode = _PowerDescriptorEnums.CurrentPowerMode
+    PowerSources = _PowerDescriptorEnums.PowerSources
+    PowerSourceLevel = _PowerDescriptorEnums.PowerSourceLevel
+
+    current_power_mode: _PowerDescriptorEnums.CurrentPowerMode
+    available_power_sources: _PowerDescriptorEnums.PowerSources
+    current_power_source: _PowerDescriptorEnums.PowerSources
+    current_power_source_level: _PowerDescriptorEnums.PowerSourceLevel
 
 
 class SimpleDescriptor(t.Struct):
-    _fields = [
-        ("endpoint", t.uint8_t),
-        ("profile", t.uint16_t),
-        ("device_type", t.uint16_t),
-        ("device_version", t.uint8_t),
-        ("input_clusters", t.LVList(t.uint16_t)),
-        ("output_clusters", t.LVList(t.uint16_t)),
-    ]
+    endpoint: t.uint8_t
+    profile: t.uint16_t
+    device_type: t.uint16_t
+    device_version: t.uint8_t
+    input_clusters: t.LVList[t.uint16_t]
+    output_clusters: t.LVList[t.uint16_t]
 
 
 class SizePrefixedSimpleDescriptor(SimpleDescriptor):
@@ -33,242 +56,312 @@ class SizePrefixedSimpleDescriptor(SimpleDescriptor):
         return super().deserialize(data[1:])
 
 
-class LogicalType(t.enum8):
+class LogicalType(t.enum3):
     Coordinator = 0b000
     Router = 0b001
     EndDevice = 0b010
-    Reserved3 = 0b011
-    Reserved4 = 0b100
-    Reserved5 = 0b101
-    Reserved6 = 0b110
-    Reserved7 = 0b111
+
+
+class _NodeDescriptorEnums:
+    class MACCapabilityFlags(t.bitmap8):
+        NONE = 0
+
+        AlternatePanCoordinator = 0b00000001
+        FullFunctionDevice = 0b00000010
+        MainsPowered = 0b00000100
+        RxOnWhenIdle = 0b00001000
+        SecurityCapable = 0b01000000
+        AllocateAddress = 0b10000000
+
+    class FrequencyBand(t.bitmap5):
+        Freq868MHz = 0b00001
+        Freq902MHz = 0b00100
+        Freq2400MHz = 0b01000
+
+    class DescriptorCapability(t.bitmap8):
+        NONE = 0
+
+        ExtendedActiveEndpointListAvailable = 0b00000001
+        ExtendedSimpleDescriptorListAvailable = 0b00000010
 
 
 class NodeDescriptor(t.Struct):
-    byte1: t.uint8_t
-    byte2: t.uint8_t
-    mac_capability_flags: t.uint8_t
+    FrequencyBand = _NodeDescriptorEnums.FrequencyBand
+    MACCapabilityFlags = _NodeDescriptorEnums.MACCapabilityFlags
+    DescriptorCapability = _NodeDescriptorEnums.DescriptorCapability
+
+    logical_type: LogicalType
+    complex_descriptor_available: t.uint1_t
+    user_descriptor_available: t.uint1_t
+    reserved: t.uint3_t
+
+    aps_flags: t.uint3_t
+    frequency_band: _NodeDescriptorEnums.FrequencyBand
+
+    mac_capability_flags: _NodeDescriptorEnums.MACCapabilityFlags
     manufacturer_code: t.uint16_t
     maximum_buffer_size: t.uint8_t
     maximum_incoming_transfer_size: t.uint16_t
     server_mask: t.uint16_t
     maximum_outgoing_transfer_size: t.uint16_t
-    descriptor_capability_field: t.uint8_t
+    descriptor_capability_field: _NodeDescriptorEnums.DescriptorCapability
 
-    _fields = [
-        ("byte1", t.uint8_t),
-        ("byte2", t.uint8_t),
-        ("mac_capability_flags", t.uint8_t),
-        ("manufacturer_code", t.uint16_t),
-        ("maximum_buffer_size", t.uint8_t),
-        ("maximum_incoming_transfer_size", t.uint16_t),
-        ("server_mask", t.uint16_t),
-        ("maximum_outgoing_transfer_size", t.uint16_t),
-        ("descriptor_capability_field", t.uint8_t),
-    ]
+    def __new__(cls, *args, **kwargs):
+        # Old style constructor
+        if len(args) == 9 or "byte1" in kwargs or "byte2" in kwargs:
+            return cls._old_constructor(*args, **kwargs)
+
+        return super().__new__(cls, *args, **kwargs)
+
+    @classmethod
+    def _old_constructor(
+        cls: "NodeDescriptor",
+        byte1: t.uint8_t = None,
+        byte2: t.uint8_t = None,
+        mac_capability_flags: MACCapabilityFlags = None,
+        manufacturer_code: t.uint16_t = None,
+        maximum_buffer_size: t.uint8_t = None,
+        maximum_incoming_transfer_size: t.uint16_t = None,
+        server_mask: t.uint16_t = None,
+        maximum_outgoing_transfer_size: t.uint16_t = None,
+        descriptor_capability_field: t.uint8_t = None,
+    ) -> NodeDescriptor:
+        logical_type = None
+        complex_descriptor_available = None
+        user_descriptor_available = None
+        reserved = None
+
+        if byte1 is not None:
+            bits, _ = t.Bits.deserialize(bytes([byte1]))
+            logical_type, bits = LogicalType.from_bits(bits)
+            complex_descriptor_available, bits = t.uint1_t.from_bits(bits)
+            user_descriptor_available, bits = t.uint1_t.from_bits(bits)
+            reserved, bits = t.uint3_t.from_bits(bits)
+
+            assert not bits
+
+        aps_flags = None
+        frequency_band = None
+
+        if byte2 is not None:
+            bits, _ = t.Bits.deserialize(bytes([byte2]))
+            aps_flags, bits = t.uint3_t.from_bits(bits)
+            frequency_band, bits = cls.FrequencyBand.from_bits(bits)
+
+            assert not bits
+
+        return cls(
+            logical_type=logical_type,
+            complex_descriptor_available=complex_descriptor_available,
+            user_descriptor_available=user_descriptor_available,
+            reserved=reserved,
+            aps_flags=aps_flags,
+            frequency_band=frequency_band,
+            mac_capability_flags=mac_capability_flags,
+            manufacturer_code=manufacturer_code,
+            maximum_buffer_size=maximum_buffer_size,
+            maximum_incoming_transfer_size=maximum_incoming_transfer_size,
+            server_mask=server_mask,
+            maximum_outgoing_transfer_size=maximum_outgoing_transfer_size,
+            descriptor_capability_field=descriptor_capability_field,
+        )
 
     @property
-    def is_valid(self):
-        """Return True if all fields were initialized."""
-        non_empty_fields = [
-            getattr(self, field[0]) is not None for field in self._fields
-        ]
-        return all(non_empty_fields)
-
-    @property
-    def logical_type(self):
-        """Return logical type of the device"""
-        if self.byte1 is None:
-            return None
-        return LogicalType(self.byte1 & 0x07)
-
-    @property
-    def is_coordinator(self):
-        """Return True whether this is a coordinator."""
+    def is_end_device(self) -> bool | None:
         if self.logical_type is None:
             return None
-        return self.logical_type == LogicalType.Coordinator
 
-    @property
-    def is_end_device(self):
-        """Return True whether this is an end device."""
-        if self.logical_type is None:
-            return None
         return self.logical_type == LogicalType.EndDevice
 
     @property
-    def is_router(self):
-        """Return True whether this is a router."""
+    def is_router(self) -> bool | None:
         if self.logical_type is None:
             return None
+
         return self.logical_type == LogicalType.Router
 
     @property
-    def complex_descriptor_available(self):
-        if self.byte1 is None:
+    def is_coordinator(self) -> bool | None:
+        if self.logical_type is None:
             return None
-        return bool(self.byte1 & 0b00001000)
+
+        return self.logical_type == LogicalType.Coordinator
 
     @property
-    def user_descriptor_available(self):
-        if self.byte1 is None:
-            return None
-        return bool(self.byte1 & 0b00010000)
-
-    @property
-    def is_alternate_pan_coordinator(self):
+    def is_alternate_pan_coordinator(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b00000001)
+
+        return bool(
+            self.mac_capability_flags & self.MACCapabilityFlags.AlternatePanCoordinator
+        )
 
     @property
-    def is_full_function_device(self):
+    def is_full_function_device(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b00000010)
+
+        return bool(
+            self.mac_capability_flags & self.MACCapabilityFlags.FullFunctionDevice
+        )
 
     @property
-    def is_mains_powered(self):
+    def is_mains_powered(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b00000100)
+
+        return bool(self.mac_capability_flags & self.MACCapabilityFlags.MainsPowered)
 
     @property
-    def is_receiver_on_when_idle(self):
+    def is_receiver_on_when_idle(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b00001000)
+
+        return bool(self.mac_capability_flags & self.MACCapabilityFlags.RxOnWhenIdle)
 
     @property
-    def is_security_capable(self):
+    def is_security_capable(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b01000000)
+
+        return bool(self.mac_capability_flags & self.MACCapabilityFlags.SecurityCapable)
 
     @property
-    def allocate_address(self):
+    def allocate_address(self) -> bool | None:
         if self.mac_capability_flags is None:
             return None
-        return bool(self.mac_capability_flags & 0b10000000)
+
+        return bool(self.mac_capability_flags & self.MACCapabilityFlags.AllocateAddress)
 
 
-class MultiAddress:
+class MultiAddress(t.Struct):
     """Used for binds, represents an IEEE+endpoint or NWK address"""
 
-    def __init__(self, other=None):
-        if isinstance(other, self.__class__):
-            self.addrmode = other.addrmode
-            self.nwk = getattr(other, "nwk", None)
-            self.ieee = getattr(other, "ieee", None)
-            self.endpoint = getattr(other, "endpoint", None)
+    addrmode: t.uint8_t
+    nwk: t.uint16_t = t.StructField(requires=lambda s: s.addrmode == 0x01)
+    ieee: t.EUI64 = t.StructField(requires=lambda s: s.addrmode == 0x03)
+    endpoint: t.uint8_t = t.StructField(requires=lambda s: s.addrmode == 0x03)
 
     @classmethod
     def deserialize(cls, data):
-        r = cls()
-        r.addrmode, data = data[0], data[1:]
-        if r.addrmode == 0x01:
-            r.nwk, data = t.uint16_t.deserialize(data)
-        elif r.addrmode == 0x03:
-            r.ieee, data = t.EUI64.deserialize(data)
-            r.endpoint, data = t.uint8_t.deserialize(data)
-        else:
+        r, data = super().deserialize(data)
+
+        if r.addrmode not in (0x01, 0x03):
             raise ValueError("Invalid MultiAddress - unknown address mode")
 
         return r, data
 
     def serialize(self):
-        if self.addrmode == 0x01:
-            return self.addrmode.to_bytes(1, "little") + self.nwk.to_bytes(2, "little")
-        elif self.addrmode == 0x03:
-            return (
-                self.addrmode.to_bytes(1, "little")
-                + self.ieee.serialize()
-                + self.endpoint.to_bytes(1, "little")
-            )
-        else:
-            raise ValueError("Invalid value for addrmode")
+        if self.addrmode not in (0x01, 0x03):
+            raise ValueError("Invalid MultiAddress - unknown address mode")
+
+        return super().serialize()
+
+
+class _NeighborEnums:
+    class DeviceType(t.enum2):
+        Coordinator = 0x0
+        Router = 0x1
+        EndDevice = 0x2
+        Unknown = 0x3
+
+    class RxOnWhenIdle(t.enum2):
+        Off = 0x0
+        On = 0x1
+        Unknown = 0x2
+
+    class RelationShip(t.enum3):
+        Parent = 0x0
+        Child = 0x1
+        Sibling = 0x2
+        NoneOfTheAbove = 0x3
+        PreviousChild = 0x4
+
+    class PermitJoins(t.enum2):
+        NotAccepting = 0x0
+        Accepting = 0x1
+        Unknown = 0x2
 
 
 class Neighbor(t.Struct):
     """Neighbor Descriptor"""
 
-    _fields = [
-        ("PanId", t.EUI64),
-        ("IEEEAddr", t.EUI64),
-        ("NWKAddr", t.NWK),
-        ("NeighborType", t.uint8_t),
-        ("PermitJoining", t.uint8_t),
-        ("Depth", t.uint8_t),
-        ("LQI", t.uint8_t),
-    ]
+    PermitJoins = _NeighborEnums.PermitJoins
+    DeviceType = _NeighborEnums.DeviceType
+    RxOnWhenIdle = _NeighborEnums.RxOnWhenIdle
+    RelationShip = _NeighborEnums.RelationShip
+
+    extended_pan_id: t.ExtendedPanId
+    ieee: t.EUI64
+    nwk: t.NWK
+
+    device_type: _NeighborEnums.DeviceType
+    rx_on_when_idle: _NeighborEnums.RxOnWhenIdle
+    relationship: _NeighborEnums.RelationShip
+    reserved1: t.uint1_t
+
+    permit_joining: _NeighborEnums.PermitJoins
+    reserved2: t.uint6_t
+
+    depth: t.uint8_t
+    lqi: t.uint8_t
+
+    @classmethod
+    def _parse_packed(cls, packed: t.uint8_t) -> dict[str, typing.Any]:
+        data = 18 * b"\x00" + t.uint16_t(packed).serialize() + 3 * b"\x00"
+        tmp_neighbor, _ = cls.deserialize(data)
+
+        return {
+            "device_type": tmp_neighbor.device_type,
+            "rx_on_when_idle": tmp_neighbor.rx_on_when_idle,
+            "relationship": tmp_neighbor.relationship,
+            "reserved1": tmp_neighbor.reserved1,
+        }
 
 
 class Neighbors(t.Struct):
     """Mgmt_Lqi_rsp"""
 
-    _fields = [
-        ("Entries", t.uint8_t),
-        ("StartIndex", t.uint8_t),
-        ("NeighborTableList", t.LVList(Neighbor)),
-    ]
+    entries: t.uint8_t
+    start_index: t.uint8_t
+    neighbor_table_list: t.LVList[Neighbor]
 
 
 class Route(t.Struct):
     """Route Descriptor"""
 
-    _fields = [("DstNWK", t.NWK), ("RouteStatus", t.uint8_t), ("NextHop", t.NWK)]
+    DstNWK: t.NWK
+    RouteStatus: t.uint8_t
+    NextHop: t.NWK
 
 
 class Routes(t.Struct):
-    _fields = [
-        ("Entries", t.uint8_t),
-        ("StartIndex", t.uint8_t),
-        ("RoutingTableList", t.LVList(Route)),
-    ]
+    Entries: t.uint8_t
+    StartIndex: t.uint8_t
+    RoutingTableList: t.LVList[Route]
 
 
 class NwkUpdate(t.Struct):
     CHANNEL_CHANGE_REQ = 0xFE
     CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ = 0xFF
 
-    _fields = [
-        ("ScanChannels", t.Channels),
-        ("ScanDuration", t.uint8_t),
-        ("ScanCount", t.uint8_t),
-        ("nwkUpdateId", t.uint8_t),
-        ("nwkManagerAddr", t.NWK),
-    ]
+    ScanChannels: t.Channels
+    ScanDuration: t.uint8_t
+    ScanCount: t.uint8_t = t.StructField(requires=lambda s: s.ScanDuration <= 0x05)
+    nwkUpdateId: t.uint8_t = t.StructField(
+        requires=lambda s: s.ScanDuration
+        in (s.CHANNEL_CHANGE_REQ, s.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ)
+    )
+    nwkManagerAddr: t.NWK = t.StructField(
+        requires=lambda s: s.ScanDuration == s.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ
+    )
 
-    def serialize(self) -> bytes:
-        """Serialize data."""
-        r = self.ScanChannels.serialize() + self.ScanDuration.serialize()
-        if self.ScanDuration <= 0x05:
-            r += self.ScanCount.serialize()
-        if self.ScanDuration in (
-            self.CHANNEL_CHANGE_REQ,
-            self.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ,
-        ):
-            r += self.nwkUpdateId.serialize()
-        if self.ScanDuration == self.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ:
-            r += self.nwkManagerAddr.serialize()
-        return r
 
-    @classmethod
-    def deserialize(cls, data: bytes) -> typing.Tuple["NwkUpdate", bytes]:
-        """Deserialize data."""
-        r = cls()
-        r.ScanChannels, data = t.Channels.deserialize(data)
-        r.ScanDuration, data = t.uint8_t.deserialize(data)
-        if r.ScanDuration <= 0x05:
-            r.ScanCount, data = t.uint8_t.deserialize(data)
-        if r.ScanDuration in (
-            cls.CHANNEL_CHANGE_REQ,
-            cls.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ,
-        ):
-            r.nwkUpdateId, data = t.uint8_t.deserialize(data)
-        if r.ScanDuration == cls.CHANNEL_MASK_MANAGER_ADDR_CHANGE_REQ:
-            r.nwkManagerAddr, data = t.NWK.deserialize(data)
-        return r, data
+class Binding(t.Struct):
+    SrcAddress: t.EUI64
+    SrcEndpoint: t.uint8_t
+    ClusterId: t.uint16_t
+    DstAddress: MultiAddress
 
 
 class Status(t.enum8):
@@ -310,7 +403,7 @@ class Status(t.enum8):
     @classmethod
     def _missing_(cls, value):
         chained = t.APSStatus(value)
-        status = t.uint8_t.__new__(cls, chained.value)
+        status = cls._member_type_.__new__(cls, chained.value)
         status._name_ = chained.name
         status._value_ = value
         return status
@@ -322,8 +415,8 @@ IEEE = ("IEEEAddr", t.EUI64)
 STATUS = ("Status", Status)
 
 
-class _CommandID(t.HexRepr, t.uint16_t):
-    _hex_len = 4
+class _CommandID(t.uint16_t, repr="hex"):
+    pass
 
 
 class ZDOCmd(t.enum_factory(_CommandID)):
@@ -358,6 +451,7 @@ class ZDOCmd(t.enum_factory(_CommandID)):
     # ... TODO optional stuff ...
     Mgmt_Lqi_req = 0x0031
     Mgmt_Rtg_req = 0x0032
+    Mgmt_Bind_req = 0x0033
     # ... TODO optional stuff ...
     Mgmt_Leave_req = 0x0034
     Mgmt_Permit_Joining_req = 0x0036
@@ -396,6 +490,7 @@ class ZDOCmd(t.enum_factory(_CommandID)):
     # Network Management Server Services Responses
     Mgmt_Lqi_rsp = 0x8031
     Mgmt_Rtg_rsp = 0x8032
+    Mgmt_Bind_rsp = 0x8033
     # ... TODO optional stuff ...
     Mgmt_Leave_rsp = 0x8034
     Mgmt_Permit_Joining_rsp = 0x8036
@@ -414,8 +509,8 @@ CLUSTERS = {
     ZDOCmd.Match_Desc_req: (
         NWKI,
         ("ProfileID", t.uint16_t),
-        ("InClusterList", t.LVList(t.uint16_t)),
-        ("OutClusterList", t.LVList(t.uint16_t)),
+        ("InClusterList", t.LVList[t.uint16_t]),
+        ("OutClusterList", t.LVList[t.uint16_t]),
     ),
     # ZDO.Complex_Desc_req: (NWKI, ),
     ZDOCmd.User_Desc_req: (NWKI,),
@@ -423,7 +518,7 @@ CLUSTERS = {
     ZDOCmd.Device_annce: (NWK, IEEE, ("Capability", t.uint8_t)),
     ZDOCmd.User_Desc_set: (
         NWKI,
-        ("UserDescriptor", t.fixed_list(16, t.uint8_t)),
+        ("UserDescriptor", t.FixedList[16, t.uint8_t]),
     ),  # Really a string
     ZDOCmd.System_Server_Discovery_req: (("ServerMask", t.uint16_t),),
     ZDOCmd.Discovery_store_req: (
@@ -432,10 +527,10 @@ CLUSTERS = {
         ("NodeDescSize", t.uint8_t),
         ("PowerDescSize", t.uint8_t),
         ("ActiveEPSize", t.uint8_t),
-        ("SimpleDescSizeList", t.LVList(t.uint8_t)),
+        ("SimpleDescSizeList", t.LVList[t.uint8_t]),
     ),
     ZDOCmd.Node_Desc_store_req: (NWK, IEEE, ("NodeDescriptor", NodeDescriptor)),
-    ZDOCmd.Active_EP_store_req: (NWK, IEEE, ("ActiveEPList", t.LVList(t.uint8_t))),
+    ZDOCmd.Active_EP_store_req: (NWK, IEEE, ("ActiveEPList", t.LVList[t.uint8_t])),
     ZDOCmd.Simple_Desc_store_req: (
         NWK,
         IEEE,
@@ -449,15 +544,15 @@ CLUSTERS = {
         ("StartIndex", t.uint8_t),
     ),
     ZDOCmd.Extended_Active_EP_req: (NWKI, ("StartIndex", t.uint8_t)),
-    ZDOCmd.Parent_annce: (("Children", t.LVList(t.EUI64)),),
+    ZDOCmd.Parent_annce: (("Children", t.LVList[t.EUI64]),),
     #  Bind Management Server Services Responses
     ZDOCmd.End_Device_Bind_req: (
         ("BindingTarget", t.uint16_t),
         ("SrcAddress", t.EUI64),
         ("SrcEndpoint", t.uint8_t),
         ("ProfileID", t.uint8_t),
-        ("InClusterList", t.LVList(t.uint8_t)),
-        ("OutClusterList", t.LVList(t.uint8_t)),
+        ("InClusterList", t.LVList[t.uint8_t]),
+        ("OutClusterList", t.LVList[t.uint8_t]),
     ),
     ZDOCmd.Bind_req: (
         ("SrcAddress", t.EUI64),
@@ -475,6 +570,7 @@ CLUSTERS = {
     # ... TODO optional stuff ...
     ZDOCmd.Mgmt_Lqi_req: (("StartIndex", t.uint8_t),),
     ZDOCmd.Mgmt_Rtg_req: (("StartIndex", t.uint8_t),),
+    ZDOCmd.Mgmt_Bind_req: (("StartIndex", t.uint8_t),),
     # ... TODO optional stuff ...
     ZDOCmd.Mgmt_Leave_req: (("DeviceAddress", t.EUI64), ("Options", t.bitmap8)),
     ZDOCmd.Mgmt_Permit_Joining_req: (
@@ -491,7 +587,7 @@ CLUSTERS = {
         NWK,
         ("NumAssocDev", t.Optional(t.uint8_t)),
         ("StartIndex", t.Optional(t.uint8_t)),
-        ("NWKAddressAssocDevList", t.Optional(t.List(t.NWK))),
+        ("NWKAddressAssocDevList", t.Optional(t.List[t.NWK])),
     ),
     ZDOCmd.IEEE_addr_rsp: (
         STATUS,
@@ -499,7 +595,7 @@ CLUSTERS = {
         NWK,
         ("NumAssocDev", t.Optional(t.uint8_t)),
         ("StartIndex", t.Optional(t.uint8_t)),
-        ("NWKAddrAssocDevList", t.Optional(t.List(t.NWK))),
+        ("NWKAddrAssocDevList", t.Optional(t.List[t.NWK])),
     ),
     ZDOCmd.Node_Desc_rsp: (
         STATUS,
@@ -516,8 +612,8 @@ CLUSTERS = {
         NWKI,
         ("SimpleDescriptor", t.Optional(SizePrefixedSimpleDescriptor)),
     ),
-    ZDOCmd.Active_EP_rsp: (STATUS, NWKI, ("ActiveEPList", t.LVList(t.uint8_t))),
-    ZDOCmd.Match_Desc_rsp: (STATUS, NWKI, ("MatchList", t.LVList(t.uint8_t))),
+    ZDOCmd.Active_EP_rsp: (STATUS, NWKI, ("ActiveEPList", t.LVList[t.uint8_t])),
+    ZDOCmd.Match_Desc_rsp: (STATUS, NWKI, ("MatchList", t.LVList[t.uint8_t])),
     # ZDO.Complex_Desc_rsp: (
     #     STATUS,
     #     NWKI,
@@ -528,7 +624,7 @@ CLUSTERS = {
         STATUS,
         NWKI,
         ("Length", t.uint8_t),
-        ("UserDescriptor", t.Optional(t.fixed_list(16, t.uint8_t))),
+        ("UserDescriptor", t.Optional(t.FixedList[16, t.uint8_t])),
     ),
     ZDOCmd.Discovery_Cache_rsp: (STATUS,),
     ZDOCmd.User_Desc_conf: (STATUS, NWKI),
@@ -547,16 +643,16 @@ CLUSTERS = {
         ("AppInputClusterCount", t.uint8_t),
         ("AppOutputClusterCount", t.uint8_t),
         ("StartIndex", t.uint8_t),
-        ("AppClusterList", t.Optional(t.List(t.uint16_t))),
+        ("AppClusterList", t.Optional(t.List[t.uint16_t])),
     ),
     ZDOCmd.Extended_Active_EP_rsp: (
         STATUS,
         NWKI,
         ("ActiveEPCount", t.uint8_t),
         ("StartIndex", t.uint8_t),
-        ("ActiveEPList", t.List(t.uint8_t)),
+        ("ActiveEPList", t.List[t.uint8_t]),
     ),
-    ZDOCmd.Parent_annce_rsp: (STATUS, ("Children", t.LVList(t.EUI64))),
+    ZDOCmd.Parent_annce_rsp: (STATUS, ("Children", t.LVList[t.EUI64])),
     #  Bind Management Server Services Responses
     ZDOCmd.End_Device_Bind_rsp: (STATUS,),
     ZDOCmd.Bind_rsp: (STATUS,),
@@ -565,6 +661,12 @@ CLUSTERS = {
     # Network Management Server Services Responses
     ZDOCmd.Mgmt_Lqi_rsp: (STATUS, ("Neighbors", t.Optional(Neighbors))),
     ZDOCmd.Mgmt_Rtg_rsp: (STATUS, ("Routes", t.Optional(Routes))),
+    ZDOCmd.Mgmt_Bind_rsp: (
+        STATUS,
+        ("BindingTableEntries", t.uint8_t),
+        ("StartIndex", t.uint8_t),
+        ("BindingTableList", t.LVList[Binding]),
+    ),
     # ... TODO optional stuff ...
     ZDOCmd.Mgmt_Leave_rsp: (STATUS,),
     ZDOCmd.Mgmt_Permit_Joining_rsp: (STATUS,),
@@ -573,7 +675,7 @@ CLUSTERS = {
         ("ScannedChannels", t.Channels),
         ("TotalTransmissions", t.uint16_t),
         ("TransmissionFailures", t.uint16_t),
-        ("EnergyValues", t.LVList(t.uint8_t)),
+        ("EnergyValues", t.LVList[t.uint8_t]),
     )
     # ... TODO optional stuff ...
 }
